@@ -13,7 +13,7 @@ class Test(Tool):
     """
     The test implementation of the Tool class.
     """
-    def __init__(self, tool_args, output_name, inputs, output_path):
+    def __init__(self, tool_args, output_name, inputs, output_path, **kwargs):
         super().__init__(
             tool_name="test",
             tool_version="0.1.0",
@@ -28,4 +28,5 @@ class Test(Tool):
             output_type=OutputType.GZ_TAR,
             output_is_directory=True,
             output_names=["test_output.txt"],
+            **kwargs,
         )
